]> sigrok.org Git - libsigrokdecode.git/blobdiff - util.c
sr/srd: Add ChangeLog to ignore list, it's generated.
[libsigrokdecode.git] / util.c
diff --git a/util.c b/util.c
index 680d3b1ce55c51166490589fbc53e0857163d3f2..6dbeb2f249acce02fe953340c146f847d6a1cf6c 100644 (file)
--- a/util.c
+++ b/util.c
@@ -22,9 +22,8 @@
 #include "sigrokdecode-internal.h"
 #include "config.h"
 
-
 /**
- * Get the value of a python object's attribute, returned as a newly
+ * Get the value of a Python object's attribute, returned as a newly
  * allocated char *.
  *
  * @param py_obj The object to probe.
  * @return SRD_OK upon success, a (negative) error code otherwise.
  *         The 'outstr' argument points to a malloc()ed string upon success.
  */
-int py_attr_as_str(PyObject *py_obj, const char *attr, char **outstr)
+SRD_PRIV int py_attr_as_str(const PyObject *py_obj, const char *attr,
+                           char **outstr)
 {
        PyObject *py_str;
        int ret;
 
-       if (!PyObject_HasAttrString(py_obj, attr)) {
+       if (!PyObject_HasAttrString((PyObject *)py_obj, attr)) {
                srd_dbg("%s object has no attribute '%s'.",
                        Py_TYPE(py_obj)->tp_name, attr);
                return SRD_ERR_PYTHON;
        }
 
-       if (!(py_str = PyObject_GetAttrString(py_obj, attr))) {
-               catch_exception("");
+       if (!(py_str = PyObject_GetAttrString((PyObject *)py_obj, attr))) {
+               srd_exception_catch("");
                return SRD_ERR_PYTHON;
        }
 
@@ -63,9 +63,8 @@ int py_attr_as_str(PyObject *py_obj, const char *attr, char **outstr)
        return ret;
 }
 
-
 /**
- * Get the value of a python dictionary item, returned as a newly
+ * Get the value of a Python dictionary item, returned as a newly
  * allocated char *.
  *
  * @param py_obj The dictionary to probe.
@@ -75,35 +74,36 @@ int py_attr_as_str(PyObject *py_obj, const char *attr, char **outstr)
  * @return SRD_OK upon success, a (negative) error code otherwise.
  *         The 'outstr' argument points to a malloc()ed string upon success.
  */
-int py_dictitem_as_str(PyObject *py_obj, const char *key, char **outstr)
+SRD_PRIV int py_dictitem_as_str(const PyObject *py_obj, const char *key,
+                               char **outstr)
 {
        PyObject *py_value;
        int ret;
 
-       if (!PyDict_Check(py_obj)) {
-               srd_dbg("Object is a %s, not a dictionary.", Py_TYPE(py_obj)->tp_name);
+       if (!PyDict_Check((PyObject *)py_obj)) {
+               srd_dbg("Object is a %s, not a dictionary.",
+                       Py_TYPE((PyObject *)py_obj)->tp_name);
                return SRD_ERR_PYTHON;
        }
 
-       if (!(py_value = PyDict_GetItemString(py_obj, key))) {
+       if (!(py_value = PyDict_GetItemString((PyObject *)py_obj, key))) {
                srd_dbg("Dictionary has no attribute '%s'.", key);
                return SRD_ERR_PYTHON;
        }
 
        if (!PyUnicode_Check(py_value)) {
-               srd_dbg("Dictionary value for %s should be a string, but is a %s.",
-                       key, Py_TYPE(py_value)->tp_name);
+               srd_dbg("Dictionary value for %s should be a string, but is "
+                       "a %s.", key, Py_TYPE(py_value)->tp_name);
                return SRD_ERR_PYTHON;
        }
 
        ret = py_str_as_str(py_value, outstr);
 
-       return SRD_OK;
+       return ret;
 }
 
-
 /**
- * Get the value of a python unicode string object, returned as a newly
+ * Get the value of a Python unicode string object, returned as a newly
  * allocated char *.
  *
  * @param py_str The unicode string object.
@@ -112,7 +112,7 @@ int py_dictitem_as_str(PyObject *py_obj, const char *key, char **outstr)
  * @return SRD_OK upon success, a (negative) error code otherwise.
  *         The 'outstr' argument points to a malloc()ed string upon success.
  */
-int py_str_as_str(PyObject *py_str, char **outstr)
+SRD_PRIV int py_str_as_str(const PyObject *py_str, char **outstr)
 {
        PyObject *py_encstr;
        int ret;
@@ -122,13 +122,15 @@ int py_str_as_str(PyObject *py_str, char **outstr)
        str = NULL;
        ret = SRD_OK;
 
-       if (!PyUnicode_Check(py_str)) {
-               srd_dbg("Object is a %s, not a string object.", Py_TYPE(py_str)->tp_name);
+       if (!PyUnicode_Check((PyObject *)py_str)) {
+               srd_dbg("Object is a %s, not a string object.",
+                       Py_TYPE((PyObject *)py_str)->tp_name);
                ret = SRD_ERR_PYTHON;
                goto err_out;
        }
 
-       if (!(py_encstr = PyUnicode_AsEncodedString(py_str, "utf-8", NULL))) {
+       if (!(py_encstr = PyUnicode_AsEncodedString((PyObject *)py_str,
+           "utf-8", NULL))) {
                ret = SRD_ERR_PYTHON;
                goto err_out;
        }
@@ -138,7 +140,7 @@ int py_str_as_str(PyObject *py_str, char **outstr)
        }
 
        if (!(*outstr = g_strdup(str))) {
-               srd_dbg("outstr malloc failed");
+               srd_dbg("Failed to g_malloc() outstr.");
                ret = SRD_ERR_MALLOC;
                goto err_out;
        }
@@ -148,35 +150,36 @@ err_out:
                Py_XDECREF(py_encstr);
 
        if (PyErr_Occurred()) {
-               catch_exception("string conversion failed");
+               srd_exception_catch("string conversion failed");
        }
 
        return ret;
 }
 
-
 /**
- * Convert a python list of unicode strings to a NULL-terminated UTF8-encoded
- * char * array. The caller must free each string when finished.
+ * Convert a Python list of unicode strings to a NULL-terminated UTF8-encoded
+ * char * array. The caller must g_free() each string when finished.
  *
  * @param py_strlist The list object.
  * @param outstr ptr to char ** storage to be filled in.
  *
  * @return SRD_OK upon success, a (negative) error code otherwise.
*         The 'outstr' argument points to a malloc()ed char ** upon success.
  */
-int py_strlist_to_char(PyObject *py_strlist, char ***outstr)
+SRD_PRIV int py_strlist_to_char(const PyObject *py_strlist, char ***outstr)
 {
        PyObject *py_str;
        int list_len, i;
        char **out, *str;
 
-       list_len = PyList_Size(py_strlist);
-       if (!(out = g_try_malloc(sizeof(char *) * (list_len + 1))))
+       list_len = PyList_Size((PyObject *)py_strlist);
+       if (!(out = g_try_malloc(sizeof(char *) * (list_len + 1)))) {
+               srd_err("Failed to g_malloc() 'out'.");
                return SRD_ERR_MALLOC;
+       }
        for (i = 0; i < list_len; i++) {
                if (!(py_str = PyUnicode_AsEncodedString(
-                               PyList_GetItem(py_strlist, i), "utf-8", NULL)))
+                   PyList_GetItem((PyObject *)py_strlist, i), "utf-8", NULL)))
                        return SRD_ERR_PYTHON;
                if (!(str = PyBytes_AS_STRING(py_str)))
                        return SRD_ERR_PYTHON;
@@ -187,4 +190,3 @@ int py_strlist_to_char(PyObject *py_strlist, char ***outstr)
 
        return SRD_OK;
 }
-
@@ -148,35 +150,36 @@ err_out:
  *
  * @return SRD_OK upon success, a (negative) error code otherwise.
- *         The 'outstr' argument points to a malloc()ed char ** upon success.
+ *         The 'outstr' argument points to a g_malloc()ed char** upon success.
  */